@@ -4,7 +4,7 @@
 
 ;; Author: Vasilij Schneidermann <v.schneidermann@gmail.com>
 ;; URL: https://github.com/wasamasa/eyebrowse
-;; Version: 0.7.7
+;; Version: 0.7.8
 ;; Package-Requires: ((dash "2.7.0") (emacs "24.3.1"))
 ;; Keywords: convenience
 
@@ -95,10 +95,13 @@ nil, 'hide: Don't show at all.
 
 'smart: Hide when only one window config.
 
+'current: Only show current config.
+
 t, 'always: Always show."
   :type '(choice (const :tag "Hide" hide)
                  (const :tag "Smart" smart)
-                 (const :tag "Always" always))
+                 (const :tag "Always" always)
+                 (const :tag "Current" current))
   :group 'eyebrowse)
 
 (defcustom eyebrowse-wrap-around nil
@@ -144,6 +147,16 @@ t: Clean up and display the scratch buffer."
   :type 'hook
   :group 'eyebrowse)
 
+(defcustom eyebrowse-pre-window-delete-hook nil
+  "Hook run before deleting a window config."
+  :type 'hook
+  :group 'eyebrowse)
+
+(defcustom eyebrowse-default-workspace-slot 1
+  "Slot number assigned to the default workspace."
+  :type 'integer
+  :group 'eyebrowse)
+
 (defcustom eyebrowse-slot-format "%s"
   "Format string for untagged slots.
 The following format codes are supported:
@@ -169,27 +182,27 @@ If t, ask for confirmation."
   :group 'eyebrowse)
 
 (defvar eyebrowse-mode-map
-  (let ((map (make-sparse-keymap)))
-    (let ((prefix-map (make-sparse-keymap)))
-      (define-key prefix-map (kbd "<") 'eyebrowse-prev-window-config)
-      (define-key prefix-map (kbd ">") 'eyebrowse-next-window-config)
-      (define-key prefix-map (kbd "'") 'eyebrowse-last-window-config)
-      (define-key prefix-map (kbd "\"") 'eyebrowse-close-window-config)
-      (define-key prefix-map (kbd ",") 'eyebrowse-rename-window-config)
-      (define-key prefix-map (kbd ".") 'eyebrowse-switch-to-window-config)
-      (define-key prefix-map (kbd "0") 'eyebrowse-switch-to-window-config-0)
-      (define-key prefix-map (kbd "1") 'eyebrowse-switch-to-window-config-1)
-      (define-key prefix-map (kbd "2") 'eyebrowse-switch-to-window-config-2)
-      (define-key prefix-map (kbd "3") 'eyebrowse-switch-to-window-config-3)
-      (define-key prefix-map (kbd "4") 'eyebrowse-switch-to-window-config-4)
-      (define-key prefix-map (kbd "5") 'eyebrowse-switch-to-window-config-5)
-      (define-key prefix-map (kbd "6") 'eyebrowse-switch-to-window-config-6)
-      (define-key prefix-map (kbd "7") 'eyebrowse-switch-to-window-config-7)
-      (define-key prefix-map (kbd "8") 'eyebrowse-switch-to-window-config-8)
-      (define-key prefix-map (kbd "9") 'eyebrowse-switch-to-window-config-9)
-      (define-key prefix-map (kbd "c") 'eyebrowse-create-window-config)
-      (define-key prefix-map (kbd "C-c") 'eyebrowse-create-window-config)
-      (define-key map eyebrowse-keymap-prefix prefix-map))
+  (let ((map (make-sparse-keymap))
+        (prefix-map (make-sparse-keymap)))
+    (define-key prefix-map (kbd "<") 'eyebrowse-prev-window-config)
+    (define-key prefix-map (kbd ">") 'eyebrowse-next-window-config)
+    (define-key prefix-map (kbd "'") 'eyebrowse-last-window-config)
+    (define-key prefix-map (kbd "\"") 'eyebrowse-close-window-config)
+    (define-key prefix-map (kbd ",") 'eyebrowse-rename-window-config)
+    (define-key prefix-map (kbd ".") 'eyebrowse-switch-to-window-config)
+    (define-key prefix-map (kbd "0") 'eyebrowse-switch-to-window-config-0)
+    (define-key prefix-map (kbd "1") 'eyebrowse-switch-to-window-config-1)
+    (define-key prefix-map (kbd "2") 'eyebrowse-switch-to-window-config-2)
+    (define-key prefix-map (kbd "3") 'eyebrowse-switch-to-window-config-3)
+    (define-key prefix-map (kbd "4") 'eyebrowse-switch-to-window-config-4)
+    (define-key prefix-map (kbd "5") 'eyebrowse-switch-to-window-config-5)
+    (define-key prefix-map (kbd "6") 'eyebrowse-switch-to-window-config-6)
+    (define-key prefix-map (kbd "7") 'eyebrowse-switch-to-window-config-7)
+    (define-key prefix-map (kbd "8") 'eyebrowse-switch-to-window-config-8)
+    (define-key prefix-map (kbd "9") 'eyebrowse-switch-to-window-config-9)
+    (define-key prefix-map (kbd "c") 'eyebrowse-create-window-config)
+    (define-key prefix-map (kbd "C-c") 'eyebrowse-create-window-config)
+    (define-key map eyebrowse-keymap-prefix prefix-map)
     map)
   "Initial key map for `eyebrowse-mode'.")
 
@@ -224,10 +237,11 @@ If FRAME is nil, use current frame.  TYPE can be any of
 (defun eyebrowse-init (&optional frame)
   "Initialize Eyebrowse for the current frame."
   (unless (eyebrowse--get 'window-configs frame)
-    (eyebrowse--set 'last-slot 1 frame)
-    (eyebrowse--set 'current-slot 1 frame)
+    (eyebrowse--set 'last-slot eyebrowse-default-workspace-slot frame)
+    (eyebrowse--set 'current-slot eyebrowse-default-workspace-slot frame)
     (eyebrowse--insert-in-window-config-list
-     (eyebrowse--current-window-config 1 "") frame)))
+     (eyebrowse--current-window-config eyebrowse-default-workspace-slot "")
+     frame)))
 
 (defun eyebrowse--update-window-config-element (new-element)
   "Replace the old element with NEW-ELEMENT in the window config list.
@@ -440,6 +454,7 @@ another appropriate window config."
                  (car (last window-configs)))
           (eyebrowse-prev-window-config nil)
         (eyebrowse-next-window-config nil))
+      (run-hooks 'eyebrowse-pre-window-delete-hook)
       (eyebrowse--delete-window-config (eyebrowse--get 'last-slot)))))
 
 (defun eyebrowse-rename-window-config (slot tag)
@@ -541,6 +556,8 @@ The specific behaviour is tmux-like."
          (slot (eyebrowse-free-slot slots)))
     (eyebrowse-switch-to-window-config slot)))
 
+(defvar evil-motion-state-map)
+
 ;;;###autoload
 (defun eyebrowse-setup-evil-keys ()
   "Set up key bindings specific to Evil.
@@ -551,14 +568,15 @@ Currently only gt, gT, gc and zx are supported."
   (define-key evil-motion-state-map (kbd "zx") 'eyebrowse-last-window-config))
 
 ;;;###autoload
-(defun eyebrowse-setup-opinionated-keys ()
+(defun eyebrowse-setup-opinionated-keys (&optional ignore-evil)
   "Set up more opinionated key bindings for using eyebrowse.
 
-M-0..M-9, C-< / C->, C-'and C-\" are used for switching.  If Evil
-is detected, extra key bindings will be set up with
-`eyebrowse-setup-evil-keys' as well."
+M-0..M-9, C-< / C->, C-'and C-\" are used for switching.  If
+IGNORE-EVIL isn't set and Evil is detected, extra key bindings
+will be set up with `eyebrowse-setup-evil-keys' as well."
   (let ((map eyebrowse-mode-map))
-    (when (bound-and-true-p evil-mode)
+    (when (and (not ignore-evil)
+               (bound-and-true-p evil-mode))
       (eyebrowse-setup-evil-keys))
     (define-key map (kbd "C-<") 'eyebrowse-prev-window-config)
     (define-key map (kbd "C->") 'eyebrowse-next-window-config)
@@ -598,7 +616,9 @@ is detected, extra key bindings will be set up with
          (separator (propertize eyebrowse-mode-line-separator
                                 'face 'eyebrowse-mode-line-separator))
          (current-slot (eyebrowse--get 'current-slot))
-         (window-configs (eyebrowse--get 'window-configs)))
+         (window-configs (if (eq eyebrowse-mode-line-style 'current)
+                             (list (assoc current-slot (eyebrowse--get 'window-configs)))
+                           (eyebrowse--get 'window-configs))))
     (if (and eyebrowse-mode-line-style
              (not (eq eyebrowse-mode-line-style 'hide))
              (or (and (not (eq eyebrowse-mode-line-style 'smart))
@@ -616,7 +636,7 @@ is detected, extra key bindings will be set up with
                    (keymap
                     (let ((map (make-sparse-keymap)))
                       (define-key map (kbd "<mode-line><mouse-1>")
-                        (lambda (e)
+                        (lambda (_e)
                           (interactive "e")
                           (eyebrowse-switch-to-window-config slot)))
                       map))
